@@ -1,7 +1,7 @@
 /*
  * Photos - access, organize and share your photos on GNOME
  * Copyright © 2014 Pranav Kant
- * Copyright © 2012, 2013, 2014, 2015 Red Hat, Inc.
+ * Copyright © 2012, 2013, 2014 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -72,7 +72,6 @@ struct _PhotosApplicationPrivate
   GSimpleAction *set_bg_action;
   GSimpleAction *remote_display_action;
   GtkWidget *main_window;
-  PhotosBaseManager *item_mngr;
   PhotosCameraCache *camera_cache;
   PhotosModeController *mode_cntrlr;
   PhotosSearchContextState *state;
@@ -175,7 +174,13 @@ photos_application_destroy (PhotosApplication *self)
   PhotosApplicationPrivate *priv = self->priv;
 
   priv->main_window = NULL;
-  photos_application_stop_miners (self);
+
+  if (priv->miners_running != NULL)
+    {
+      photos_application_stop_miners (self);
+      g_list_free_full (priv->miners_running, g_object_unref);
+      priv->miners_running = NULL;
+    }
 }
 
 
@@ -199,7 +204,7 @@ photos_application_activate_item (PhotosApplication *self, GObject *item)
   PhotosApplicationPrivate *priv = self->priv;
 
   photos_application_create_window (self);
-  photos_base_manager_set_active_object (priv->item_mngr, item);
+  photos_base_manager_set_active_object (priv->state->item_mngr, item);
   g_application_activate (G_APPLICATION (self));
 
   /* TODO: Forward the search terms when we exit the preview */
@@ -217,10 +222,10 @@ photos_application_activate_query_executed (TrackerSparqlCursor *cursor, gpointe
   if (cursor == NULL)
     goto out;
 
-  photos_item_manager_add_item (PHOTOS_ITEM_MANAGER (priv->item_mngr), cursor);
+  photos_item_manager_add_item (PHOTOS_ITEM_MANAGER (priv->state->item_mngr), cursor);
 
   identifier = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URN, NULL);
-  item = photos_base_manager_get_object_by_id (priv->item_mngr, identifier);
+  item = photos_base_manager_get_object_by_id (priv->state->item_mngr, identifier);
 
   photos_application_activate_item (self, item);
 
@@ -240,7 +245,7 @@ photos_application_activate_result (PhotosApplication *self,
 
   priv->activation_timestamp = timestamp;
 
-  item = photos_base_manager_get_object_by_id (priv->item_mngr, identifier);
+  item = photos_base_manager_get_object_by_id (priv->state->item_mngr, identifier);
   if (item != NULL)
     photos_application_activate_item (self, item);
   else
@@ -331,7 +336,7 @@ photos_application_open_current (PhotosApplication *self)
   PhotosBaseItem *item;
   guint32 time;
 
-  item = PHOTOS_BASE_ITEM (photos_base_manager_get_active_object (priv->item_mngr));
+  item = PHOTOS_BASE_ITEM (photos_base_manager_get_active_object (priv->state->item_mngr));
   if (item == NULL)
     return;
 
@@ -347,7 +352,7 @@ photos_application_print_current (PhotosApplication *self)
   PhotosApplicationPrivate *priv = self->priv;
   PhotosBaseItem *item;
 
-  item = PHOTOS_BASE_ITEM (photos_base_manager_get_active_object (priv->item_mngr));
+  item = PHOTOS_BASE_ITEM (photos_base_manager_get_active_object (priv->state->item_mngr));
   if (item == NULL)
     return;
 
@@ -363,7 +368,7 @@ photos_application_properties (PhotosApplication *self)
   GtkWidget *dialog;
   const gchar *id;
 
-  item = photos_base_manager_get_active_object (priv->item_mngr);
+  item = photos_base_manager_get_active_object (priv->state->item_mngr);
   if (item == NULL)
     return;
 
@@ -464,7 +469,7 @@ photos_application_remote_display_current (PhotosApplication *self)
   GtkWidget *dialog;
   const gchar *urn;
 
-  item = photos_base_manager_get_active_object (priv->item_mngr);
+  item = photos_base_manager_get_active_object (priv->state->item_mngr);
   if (item == NULL)
     return;
 
@@ -520,7 +525,7 @@ photos_application_set_bg (PhotosApplication *self)
 {
   PhotosBaseItem *item;
 
-  item = PHOTOS_BASE_ITEM (photos_base_manager_get_active_object (self->priv->item_mngr));
+  item = PHOTOS_BASE_ITEM (photos_base_manager_get_active_object (self->priv->state->item_mngr));
   if (item == NULL)
     return;
 
@@ -855,8 +860,6 @@ photos_application_startup (GApplication *application)
                                               photos_application_tracker_extract_priority,
                                               g_object_ref (self));
 
-  priv->item_mngr = photos_item_manager_dup_singleton ();
-
   /* A dummy reference to keep it alive during the lifetime of the
    * application.
    */
@@ -965,12 +968,6 @@ photos_application_dispose (GObject *object)
   PhotosApplication *self = PHOTOS_APPLICATION (object);
   PhotosApplicationPrivate *priv = self->priv;
 
-  if (priv->miners_running != NULL)
-    {
-      g_list_free_full (priv->miners_running, g_object_unref);
-      priv->miners_running = NULL;
-    }
-
   if (priv->miners != NULL)
     {
       g_list_free_full (priv->miners, g_object_unref);
@@ -994,7 +991,6 @@ photos_application_dispose (GObject *object)
   g_clear_object (&priv->sel_all_action);
   g_clear_object (&priv->sel_none_action);
   g_clear_object (&priv->set_bg_action);
-  g_clear_object (&priv->item_mngr);
   g_clear_object (&priv->camera_cache);
   g_clear_object (&priv->mode_cntrlr);
   g_clear_object (&priv->extract_priority);
